;; Generated package description from window-tool-bar.el  -*- no-byte-compile: t -*-
(define-package "window-tool-bar" "0.3.0.20260101.125434" "Add tool bars inside windows" '((emacs "27.1") (compat "30")) :commit "17ddfd66e65c19f44dee41ee1b7ee1ce23ef3ed2" :authors '(("Jared Finder" . "jared@finder.org")) :maintainer '("Jared Finder" . "jared@finder.org") :keywords '("mouse") :url "http://github.com/chaosemer/window-tool-bar")
